Corrected another couple of errors where EFS8A was referenced in the seal ring
generator script instead of sky130A.
diff --git a/sky130/custom/scripts/seal_ring_generator/seal_ring_corner_abstract.mag b/sky130/custom/scripts/seal_ring_generator/seal_ring_corner_abstract.mag
index 1477b9c..68becc9 100644
--- a/sky130/custom/scripts/seal_ring_generator/seal_ring_corner_abstract.mag
+++ b/sky130/custom/scripts/seal_ring_generator/seal_ring_corner_abstract.mag
@@ -1,5 +1,5 @@
 magic
-tech EFS8A
+tech sky130A
 timestamp 1584566221
 << psubstratepdiff >>
 rect 145 1110 355 25605
diff --git a/sky130/custom/scripts/seal_ring_generator/sky130_gen_sealring.py b/sky130/custom/scripts/seal_ring_generator/sky130_gen_sealring.py
index 7289801..7e341f2 100755
--- a/sky130/custom/scripts/seal_ring_generator/sky130_gen_sealring.py
+++ b/sky130/custom/scripts/seal_ring_generator/sky130_gen_sealring.py
@@ -219,7 +219,7 @@
         print('<< end >>', file=ofile)
     
     # Create a new abstract layout TO BE called 'advSeal_6um_gen.mag'
     # This is the view in technology EFS8A.  Since there is already
     # a cell with this name that is used to generate GDS, the cell
     # will be called "seal_ring.mag" and copied to "advSeal_6um_gen.mag"
     # in the target directory.
@@ -229,7 +229,7 @@
 
     with open('seal_ring.mag', 'w') as ofile:
         print('magic', file=ofile)
-        print('tech EFS8A', file=ofile)
+        print('tech sky130A', file=ofile)
         print('timestamp 1584566829', file=ofile)
 
         # Lower left original
@@ -219,7 +219,7 @@
     
     # Create a new abstract layout TO BE called 'advSeal_6um_gen.mag'
-    # This is the view in technology EFS8A.  Since there is already
+    # This is the view in technology sky130A.  Since there is already
     # a cell with this name that is used to generate GDS, the cell
     # will be called "seal_ring.mag" and copied to "advSeal_6um_gen.mag"